/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.guacamole.rest.session;

import org.apache.guacamole.GuacamoleSession;

/**
 * Factory which creates resources that expose the contents of a given
 * GuacamoleSession.
 */
public interface SessionResourceFactory {

    /**
     * Creates a new SessionResource which exposes the contents of the
     * given GuacamoleSession.
     *
     * @param token
     *     The authentication token associated with the given session.
     *
     * @param session
     *     The GuacamoleSession whose contents should be exposed.
     *
     * @return
     *     A new SessionResource which exposes the contents of the given
     *     GuacamoleSession.
     */
    SessionResource create(String token, GuacamoleSession session);

}
